NiftyPAD
========

Neuroimaging for the Prevention of Alzheimer's Disease.

|DOI| |Licence|

A novel Python package for quantitative analysis of dynamic PET data.

.. image:: https://raw.githubusercontent.com/JJiao/NiftyPAD/master/images/Fig1.jpg

.. |DOI| image:: https://img.shields.io/badge/doi-10.1007/s12021--022--09616--0-blue
   :target: https://doi.org/10.1007/s12021-022-09616-0
.. |Licence| image:: https://img.shields.io/pypi/l/niftypad.svg?label=licence
   :target: https://github.com/AMYPAD/NiftyPAD/blob/master/LICENSE
